﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;

public class AttitudeController : MonoBehaviour
{
    public float Pitch  { get => axis.x; set => axis.x = value; }   // front +, back  - (theta)
    public float Yaw    { get => axis.y; set => axis.y = value; }   // cw    +, ccw   - (psi)
    public float Roll   { get => axis.z; set => axis.z = value; }   // left  +, right - (phi)
    public Vector3 Axis { get => axis  ; set => axis   = value; }   // Target Attitude

    public Vector3 Correction => correction;    // Result correction force
    
    [SerializeField] private Vector3 axis;
    [SerializeField] [Readonly] private Vector3 correction;

    [Header("PID Control values")]
    [SerializeField] private Vector3 KrP = new Vector3(0.5f, 0.5f, 0.5f);
    [SerializeField] private Vector3 KrI = new Vector3(0.5f, 0.5f, 0.5f);
    [SerializeField] private Vector3 KrD = new Vector3(0.2f, 0.2f, 0.2f);
    [SerializeField] [Readonly] private Vector3 pAxis, iAxis, dAxis;
    private Vector3 prevPAxis;

    private NavdataHandler navdata;

    void Start() {
        navdata = GetComponent<NavdataHandler>();
    }

    void FixedUpdate() {
        var tRotation = Quaternion.Euler(axis);
        var cRotation = Quaternion.Euler(navdata.Rotation);
        var dRotation = Quaternion.Inverse(cRotation) * tRotation;

        prevPAxis = pAxis;
        pAxis = dRotation.eulerAngles.RelativeAngles();
        iAxis += pAxis * Time.fixedDeltaTime;
        dAxis = (pAxis - prevPAxis) / Time.fixedDeltaTime;

        correction = Vector3.Scale(KrP, pAxis) + Vector3.Scale(KrI, iAxis) + Vector3.Scale(KrD, dAxis);
    }

    public void reset() => pAxis = iAxis = dAxis = prevPAxis = Vector3.zero;
}
