﻿using System.Collections;
using System.Collections.Generic;
using UnityEngine;
using UnityEditor;

public class NavdataHandler : MonoBehaviour
{
    public Vector3 Accel => acceleration;
    public Vector3 Velocity => velocity;
    public Vector3 Rotation => rotation;
    public float   Altitude => altitude;

    [SerializeField] [Readonly] private Vector3 acceleration;   // from accelerometer
    [SerializeField] [Readonly] private Vector3 velocity;       // navdata_demo calculation
    [SerializeField] [Readonly] private Vector3 rotation;       // from gyroscope + magnetometer
    [SerializeField] [Readonly] private float   altitude;       // from ultrasonic sensor
    // presure sensor skipped; not needed

    private new Rigidbody rigidbody;
    private new Transform transform;

    private Vector3 prevVelocity;

    void Start() {
        rigidbody = GetComponent<Rigidbody>();
        transform = GetComponent<Transform>();
    }

    void FixedUpdate() {
        prevVelocity = velocity;
        velocity = transform.InverseTransformDirection(rigidbody.velocity);
        acceleration = (velocity - prevVelocity) / Time.fixedDeltaTime;
        rotation = transform.eulerAngles;
        altitude = transform.position.y - 0.5f;
    }
}
